/*-
 * Copyright (c) 1999, 2000, 2001, 2002, 2003 Lev Walkin <vlm@lionet.info>.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Id: sf_cgi.h,v 1.2 2005/05/25 21:55:10 vlm Exp $
 */

#ifndef __SF_CGI_H__
#define __SF_CGI_H__

#include <sf_svect.h>

#ifdef __cplusplus
extern "C" {
#endif	/* __cplusplus */

/**************************/
/*** CGI forms handling ***/
/**************************/


/* Parse QUERY_STRING or stdin dependent on REQUEST_METHOD */

/*
 * Return names of all form fields
 */
svect *params(void);

/*
 * Get specified form field
 */
char *param(char *fieldname);

/*
 * Return a list of values of specified field
 * _flags are:
 * 0: get decoded value
 * 1: get original unmodified (url-encoded) value
 * 2: get field content type
 */
svect *param2(char *fieldname, int _flags);

/*
 * Cookies support
 */
svect	*cookies(void);
char	*cookie(char *name);

/*
 * Prepare and print the cookie to the stdout.
 */
int     set_cookie(char *name, char *value, char *optDomain, char *optPath, time_t optMaxAge, char *optComment, int optSecure);

/*
 * Convert '&' to '&amp;', '<' to '&lt;', etc.
 */
char *html_quote(const char *);		/* Leak-safe */
char *html_quote_detach(void);

/*
 * Encode and decode %%'s in URL
 */
char *url_decode(const char *urlstring);	/* leak-safe. */
char *url_encode(const char *s);		/* leak-safe. */

/*
 * Parse HTTP_ACCEPT_LANGUAGE environment variable.
 */
svect *getlanguageprefs(void);		/* Don't free() the result! */

char *limittextwidth(char *text, size_t width); /* corrupts text! */


#ifdef __cplusplus
}
#endif	/* __cplusplus */

#endif	/* __SF_CGI_H__ */
